Class: Feedback
Class Method Summary collapse
Instance Method Summary collapse
-
#gets ⇒ Object
No reading from the command line thank you very much!.
Class Method Details
.gets ⇒ Object
6 7 8 |
# File 'lib/coderunner/feedback.rb', line 6 def self.gets $stdin.gets end |
Instance Method Details
#gets ⇒ Object
No reading from the command line thank you very much!
3 4 5 |
# File 'lib/coderunner/feedback.rb', line 3 def gets #No reading from the command line thank you very much! $stdin.gets end |